@@ -2,8 +2,11 @@ package CHI::Driver::Redis::t::CHIDriverTests;
 use strict;
 use warnings;
 use CHI::Test;
+
 use base qw(CHI::t::Driver);
 
+use Test::Mock::Redis;
+
 sub testing_driver_class { 'CHI::Driver::Redis' }
 
 sub supports_expires_on_backend { 1 }
@@ -14,7 +17,8 @@ sub new_cache_options {
     return (
         $self->SUPER::new_cache_options(),
         driver_class => 'CHI::Driver::Redis',
-        server => $ENV{CHI_REDIS_SERVER} || '127.0.0.1:6379',
+        redis_class => (defined $ENV{CHI_REDIS_SERVER} ? 'Redis' : 'Test::Mock::Redis'),
+        server => $ENV{CHI_REDIS_SERVER} || undef,
         ($ENV{CHI_REDIS_PASSWORD} ? ( password => $ENV{CHI_REDIS_PASSWORD} ) : ()),
         prefix => 'test' . $$ . ':',
     );
